@@ -80,20 +80,6 @@ jomo1rancon.MCMCchain<- function(Y, X=NULL, Z=NULL, clus, beta.start=NULL, u.sta
  
   imp[(nrow(Y)+1):(2*nrow(Y)),1:ncol(Y)]=Yimp2
   Yimp=Yimp2
-  betapostmean<-apply(betapost, c(1,2), mean)
-  upostmean<-apply(upostall, c(1,2), mean)
-  omegapostmean<-apply(omegapost, c(1,2), mean)
-  covupostmean<-apply(covupost, c(1,2), mean)
-  if (output==1) {
-    cat("The posterior mean of the fixed effects estimates is:\n")
-    print(betapostmean)
-    cat("The posterior mean of the random effects estimates is:\n")
-    print(upostmean)
-    cat("The posterior mean of the level 1 covariance matrices is:\n")
-    print(omegapostmean)
-    cat("The posterior mean of the level 2 covariance matrix is:\n")
-    print(covupostmean)
-  }
   imp<-data.frame(imp)
   imp[,(ncol(Y)+ncol(X)+ncol(Z)+1)]<-factor(imp[,(ncol(Y)+ncol(X)+ncol(Z)+1)])
   levels(imp[,(ncol(Y)+ncol(X)+ncol(Z)+1)])<-previous_levels_clus
@@ -115,5 +101,19 @@ jomo1rancon.MCMCchain<- function(Y, X=NULL, Z=NULL, clus, beta.start=NULL, u.sta
   dimnames(covupost)[2] <- list(colnamcovu)
   dimnames(upostall)[1]<-list(levels(clus))
   dimnames(upostall)[2]<-list(colnamcovu)
+  betapostmean<-data.frame(apply(betapost, c(1,2), mean))
+  upostmean<-data.frame(apply(upostall, c(1,2), mean))
+  omegapostmean<-data.frame(apply(omegapost, c(1,2), mean))
+  covupostmean<-data.frame(apply(covupost, c(1,2), mean))
+  if (output==1) {
+    cat("The posterior mean of the fixed effects estimates is:\n")
+    print(t(betapostmean))
+    cat("\nThe posterior mean of the random effects estimates is:\n")
+    print(upostmean)
+    cat("\nThe posterior mean of the level 1 covariance matrices is:\n")
+    print(omegapostmean)
+    cat("\nThe posterior mean of the level 2 covariance matrix is:\n")
+    print(covupostmean)
+  }
   return(list("finimp"=imp,"collectbeta"=betapost,"collectomega"=omegapost,"collectu"=upostall, "collectcovu"=covupost))
 }
\ No newline at end of file
